bibliotheca Augustana

<<< Übersicht <<< vorige Seite
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 39. Aventiure
___________________________________________________ #### <Av wie Gvnther vn– Chrimh' vn– Hagen wurden erslagen>
| ### o nam der herre Dietrich selbe sein gewant ### im half daz er sich wafent der alte Hildebrant ### do chlagt also sere der kreftige mnan ### daz daz hvs erdiezen von siner stimme began
###### 2262 | ### Do gewan er aber wider vehten heldes mvot ### in grimme wart gewafent do der degen gvot ### æinen schilt vil vesten den nam er an die hant ### si giengen balde danne er vn– maister Hildebrant
###### 2263 | ### Do sprach von Tronge Hagene ich sihe dort her gan ### den herren Dietrich der wil vns bestan ### nach sinem starchen læide daz im hie ist geschehen ### man sol daz hivte kiesen wem man des besten mvge iehen
###### 2264 | ### Iane dvnchet sich von Berne der herre Dietrich ### nie so starck des libes von so gremlich ### vnd wil erz an vns rechen daz im ist getan ### also redet Hagen ich getar in harte wol bestan
###### 2265 | ### Dise rede horte Dietrich vnd Hildebrant ### er chom da er die reken bæde stende vant ### vzen an dem hvse gelæinet an den sal ### sinen schilt den gvoten satzte her Dietriche zetal
###### 2266 | ### In læitlichen sorgen sprach her Dietrich ### wie habt ir so geworben Gvnther kvnich rich ### wider mich ellenden waz het ich iv getan ### allez mines trostes des bin ich æine bestan
###### 2267 | ### luch endvhte niht der volle an der grozen not ### do ir vns Rvedegere den helt erslvoget tot ### nv hapt ir mir erbvnnen aller miner man ### iane het ich iv helden solher læide niht getan
| ### Gedenchet an ich selben vn– an iwer læit ### tot der iwer frivnde vn– och div arbeit ### ob ez iv zieren reken beswart iht den mvot ### owe wie rehe vnsanfte mir der tot Rvedegeres tvot
###### 2269 | ### Ez geschach ze dirre werlde nie manne laider mer ### ir gedare vbel an min vn– iwer sere ### swaz ich frveden hete div ligit von iv erslagen ### ia enkan ich nimmer mer die mine mage verchlagen
###### 2270 | ### lane si wir niht so schvldich sprach do Hagen ### ez giengen ze disem hvse die iwer degene ### gewafent wol ze flize mit æiner schar so bræit ### mich dvnchet daz div mere iv niht rehte sint geseit
###### 2271 | ### Waz sol ich mer gelovben mir sagt Hildebrant ### do mine reken gerten von Amelvnge lant ### daz ir in Rvedegere gebt vz dem sal ### do bvtet ir niwen spoten den minen reken her zetal [92b]
###### 2272 | ### Do sprach der vogt von Rine si iahen wolten tragen ### Rvedeger von hinne den hiez ich <in> versagen ### Ezeln ze læide vn– niht den dinen man ### vntz daz do Wolfhart darvmbe schelten began
###### 2273 | ### Do sprach der helt von Berne ez mvose et also sin ### Gvnther chvnich edele dvrch die zvhte din ### ergetze mich der laide di mir von dir sint geschehen ### vn– svene ez riter chvene daz ich dir des mege geiehen
###### 2274 | ### Ergibe dich mir ze gisel dv vnd din man ### so wil ich behveten so ich aller beste chan ### daz dir hie zen Hevnen ieman iht en tvot ### dv solt an mir niht vinden niwan triwe vn– allez gvot
###### 2275 | ### Daz enwelle got von himel sprach do Hagne ### daz sich dir ergeben zwene degene ### die noch so werlichen gewafent gein dir stent ### vnd noch so ledichliche vor ir vienden gent
###### 2276 | ### Ir svltez niht versprechen so redet her Dietrich ### Gvnther vnde Hagne ir beide hapt mich ### so sere beswart daz herze vn– och den mvot ### vn– welt ir michs ergetzen daz irz vil billichen tvot
###### 2277 | ### Ich gibe iv mine triwe vn– sicherliche hant ### daz ich mit iv wider heim rite in iwer lant ### ich geleite ich nach den eren oder ich gelige tot ### vn– wil dvrch iv vergezzen der minen grozlichen not
###### 2278 | ### Nv enmvotet sin niht mere sprach aber Hagne ### von vns enzimt daz mere niht <wol> ze sagene ### daz sich iv ergeben zwen also chvene man ### nv siht man bi iv nieman wan eine Hildebranden stan
###### 2279 | ### Do sprach maister Hildebrant got weiz her Hagne ### der iv den vride bevtet mit iv ze tragne ### ez chvmt noch an die stvnde daz ir in moehtet nemen ### die svone mines herren meht ir iv lazen zemen
###### 2280 | ### Ia neme ich e die svone sprach aber Hagne ### e ich so lesterliche vz æinem <gadme> ### flvhe maister Hildebrant als ir hie hapt getan ### ich want vf min triwe ir chvndet baz gein veinden stan
###### 2281 | ### Des antwurte Hildebrant zweu verwizet ir mir daz ### nv wer was der vf einem shilte vor dem Wasgensteine saz ### do im von Yspanie Walther so vil der mage slvoch ### och hapt ir noch ze zeigen an iv selben genvoch
###### 2282 | ### Do sprach der herre Dietrich daz enzimt niht helde lip ### daz si svln schelten sam div alten wip ### ich verbivte iv maister Hildebrant daz ir iht sprechet mer ### mich ellenden rechen twinget grozlichiv ser
###### 2283 | ### Lat horen sprach her Dietrich reke Hagne ### waz ir bæide sprachet vil snelle degene ### do ir mich gewafent zvo iv sahet gan ### ir iahet daz ir eine mit strite woldet mich bestan [93a]
###### 2284 | ### Ia en livgent iv dez niemen sprach Hagen der degen ### ich enwellez hie versvochen mit den starchen slegen ### ez si daz mir zebreste daz Nybelvnge swert ### mir ist zorn daz vnser beider hie ze gisel ist gegert
###### 2285 | ### Do Dietrich gehorte den grimmen Hagen mvot ### den shilt vil balde zvchte der snelle degen gvot ### wie balde gein im Hagne von der stiegen spranch ### Nybelvnges swer daz gvote vil lvte vf Dietrich erchlanch
###### 2286 | ### Do wesse wol her Dietrich daz der chvene man ### vil grimmes mvotes were shirmen im began ### der herre von Berne vor angestlichen slegen ### vil wol erchant er Hagen den vil zierlichen degen
###### 2287 | ### ovch vorht er Balmvnge ein wafen starch genvoch ### vnder wilen Dietrich mit listen wider slvoch ### vntz daz er Hagen mit strite doch betwanch ### er slvog im eine wunden div waz tief vn– lanch
###### 2288 | ### Do gedaht der herre Dietrich dv bist in not erwigen ### ich hans lvtzel ere solt dv tot vor mir geligen ### ich wil ez sus <versvchen> ob ich ertwingen chan ### dich mir ze einem gisel daz wart mit sorgen getan
###### 2289 | ### Den schilt liez er vallen sin sterche div waz groz ### Hagen von Tronge mit arm er besloz ### des wart do betwungen von im der chvene man ### Gvnther der edel darvmbe trovren began
###### 2290 | ### Hagne bant do Dietrich vn– fvort in da er vant ### die edel chvniginne vn– gab ir bi der hant ### den chvenisten reken der ie swert getrvoch ### nach ir vil starchem læide do wart si vroelich genvoch
###### 2291 | ### Vor liebe naig dem degne daz vil edel wip ### immer si dir selich din herze vn– och din lip ### dv hast mich wol ergetzet aller miner not ### daz sol ich immer dienen mich ensvome der tot
###### 2292 | ### Do sprach der herre Dietrich ir svlt in lan genesen ### edeliv chvniginne vnd mach daz noch gewesen ### wie wol er ivch ergetzet daz er iv hat getan ### er sol des niht engelten daz ir in gebvnden sehet stan
###### 2293 | ### Do hiez si Hagen fveren an sinen vngemach ### da er lach beslozen vn– da in niemen sach ### Gvnther der chvnich edel rvefen do began ### war chom der helt von Berne der hat mir leide getan
| ### Do gie im hin engegene der herre Dietrich ### Gvntheres ellen daz vil lobelich ### do en bæit och er niht mere er lief her fvr den sal ### von ir beider swerten hvob sich ein grozlicher schal
###### 2295 | ### Swie vil der herre Dietrich lange was gelobt ### Gvnther waz so sere erzvrnet vn– ertobt ### wan er nach starchem leide do sint veint was ### man sagt ez noch ze wunder daz do her Dietrich genaz
###### 2296 | ### Ir ellen vn– ir sterche beide warn groz ### palas vn– tvrne von ir slegen doz [93b] ### do si mit den swerten hiwoen vf die helm gvot ### ez het der chvnich Gvnther einen herlichen mvot
###### 2297 | ### Sit twanch in der von Berne als Hagene gcschach ### daz blvot man dvrch die ringe dem helde fliezen sach ### von æinem starchem swerte daz trvog her Dietrich ### do het gewert her Gvnther nach mvede loblichen sich
###### 2298 | ### Der herre wart gebvnden von Dietriches hant ### swie chvnige niene solten læiden solhiv bant ### er daht ob er si lieze den chvnich vn– sinen man ### alle die si fvnden die mvosen tot vor im bestan
###### 2299 | ### Dietrich von Berne der nam in bi der hant ### do fvort er in gebvnden da er Chriemhilde vant ### si sprach willechomen Gvnther ein helt vz Bvrgonde lant ### nv lone iv got Chriemhilt ob mich iwer triwe des ermant
###### 2300 | ### Er sprach ich solde iv nigen vil liebiv swester min ### ob iwer grvezen genedichlicher mehte sin ### ich weiz ivch chvniginne so zornich gemvot ### daz ir mich vnde Hagen vil swachez grvezen getvot
###### 2301 | ### Do sprach der helt von Berne vil edels chvniges wip ### ez enwart nie gisel mere so gvoter riter lip ### als ich iv vrowe here an in gegeben han ### nv svlt ir die ellenden min vil wol geniezzen lan
###### 2302 | ### Si iach si tet ez gerne do gie her Dietrich ### mit wainenden ovgen von den helden loblich ### sit rach sich grimmichliche daz Ezeln wip ### den vz erwelten degnen nam si beiden den lip
###### 2303 | ### Si lie si svnder ligen dvrch ir vngemach ### daz ir seit deweder den andern nie gesach ### vntz si ir brvoder hovbet hin fvor Hagen trvok ### der Chriemhilten rache wart an in beiden genvoch
###### 2304 | ### Do gie <div> chvniginne daz si Hagen sach ### wie rehte veintliche si zvo dem reken sprach ### welt ir mir geben widere daz ir mir hapt genomen ### so moegt ir noch wol lebende heim zvo den Bvrgonden chomen
###### 2305 | ### Do sprach der grimme Hagne div bete ist gar verlorn ### vil edeliv chvniginne ia han ich des gesworn ### daz ich den hort iht zeige die wile daz si leben ### dehainer miner herren so enwirt er nieman gegeben
###### 2306 | ### Ich bringez an ein ende so sprach daz edel wip ### do hiez si ir brvoder nemen da den lip ### man slvog im ab daz hovbet bi hare si ez trvock ### fvr den helt von Tronge do wart im leide genvok
| ### Also der vngemvote sines herren hovbet sach ### wider Chriemhilde do der reke sprach ### dv hast ez nach dinem willen ze einem ende braht ### vn– ist och reht ergangen als ich mir het gedaht
###### 2308 | ### Nv ist von Bvrgonde der edel chvnich tot ### Giselher der ivnge vn– och Gernot ### den shatz waz nv nieman wan got vn– min ### der sol dich valentinne immer gar verholn sin [94a]
###### 2309 | ### Si sprach so habt ir vbel geltes mich gewert ### so wil ich doch behalten daz Sifrides swert ### daz trvog min holder friedel do ich in ivngist sach ### an dem mir herzen leide vor allem leide geschach
###### 2310 | ### Si zoch ez von der scheide daz chvnde et niht erwern ### do dahte si den rechen des lebens behern ### si hvob ez mit ir handen daz hovpt si im abe slvoch ### daz sach der kvnich Ezel do waz im leide genvock
###### 2311 | ### Waffen sprach der fvrste wie ist nv tot gelegen ### von eines wibes handen der aller beste degen ### der ie chom ze stvrme oder ie schilt getrvoch ### swie veint aber ich im were ez ist mir leide genvok
###### 2312 | ### Do sprach der alte Hildebrant ia genivzet siz niht ### daz si in slahen toerste swaz halt mir geschiht ### swie er mich selhen braht in angestliche not ### iedoch so wil ich rehen des chvenen Trongers tot
###### 2313 | ### Hildebrant der alte ze Chriemhilde spranch ### er slvog der chvniginne eines swertes swanch ### ia tet ir div sorge von Hildebrande we ### waz maht si gehelfen daz si vil grozlichen schrei
###### 2314 | ### Do waz gelegen vber al da der vaigen lip ### ze stvckhen waz gehowen do daz edel wip ### Dietrich vn– Ezel wainen do began ### si chlagten innechliche beidev mage vn– man
###### 2315 | ### Div vil michel ere waz da gelegen tot ### die livte heten alle iamer vnd not ### mit leide waz verendet des kvniges hohzit ### als ie div liebe leide ze aller ivngiste git
###### 2316 | ### Ich enchan iv niht bescheiden was sider da geschach ### wan riter vn– vrovwen wainen man da sach ### darzvo die edeln chnehte ir lieben frivnde tot ### hie har daz mer ein ende ditze ist der Nybelvnge not

<<< Übersicht <<< vorige Seite